var TYPOGRAPHY_SIZE = {
  12: {
    fontSize: 12,
    lineHeight: 20
  },
  14: {
    fontSize: 14,
    lineHeight: 22
  },
  16: {
    fontSize: 16,
    lineHeight: 24
  },
  20: {
    fontSize: 20,
    lineHeight: 28
  },
  32: {
    fontSize: 32,
    lineHeight: 40
  }
};
var TYPOGRAPHY_WEIGHT = [
/**
 * Regular font weight
 *
 * <font-weight-absolute> ~ 400
 *
 * It should be the **DEFAULT** weight
 */
'regular',
/**
 * Bolder than `regular` weight
 *
 * <font-weight-absolute> ~ 700
 */
'bold'];
var TYPOGRAPHY_VARIANT = [
/**
 * Proportional font (which has the variable amount of horizontal space)
 *
 * It should be the **DEFAULT** variant
 */
'proportional',
/**
 * Monospaced font (which has the same amount of horizontal space)
 */
'monospace'];

var SPACING = {
  0: 0,
  4: 4,
  8: 8,
  16: 16,
  24: 24,
  40: 40,
  64: 64,
  104: 104,
  168: 168,
  272: 272,
  440: 440
};

/**
 * Unit for grid column (px)
 */
var COLUMN_UNIT = 80;
/**
 * Unit for grid gutter width (px)
 */

var GUTTER_UNIT = 24; // TODO: Grid definition with breakpoint

/**
 * Calculate px occupied by the span of the columns with gutter gap
 *
 * @param span column span count
 */

function columnSystem(span, column, gutter) {
  return span * column + (span - 1) * gutter;
}

var BORDER_RADIUS = {
  /**
   * 用途: 打ち消し用（モバイルのときに角丸じゃなくなる、などを表現する）
   */
  none: 0,

  /**
   * 用途: バッジ, 高さ40px以下の要素
   */
  4: 4,

  /**
   * 用途: サムネイル
   */
  8: 8,

  /**
   * 用途: チュートリアルツールチップ
   */
  16: 16,

  /**
   * 用途: モーダル
   */
  24: 24,

  /**
   * 真円 or 左右が丸まっている矩形 を作る時に用いる
   *
   * 用途: ボタン
   */
  oval: 999999
};

var _BREAKPOINT;
var HORIZONTAL_MIN_MARGIN = 72;
var BREAKPOINT = (_BREAKPOINT = {}, _BREAKPOINT[6] = columnSystem(6, COLUMN_UNIT, GUTTER_UNIT) + HORIZONTAL_MIN_MARGIN * 2, _BREAKPOINT[8] = columnSystem(8, COLUMN_UNIT, GUTTER_UNIT) + HORIZONTAL_MIN_MARGIN * 2, _BREAKPOINT[10] = columnSystem(10, COLUMN_UNIT, GUTTER_UNIT) + HORIZONTAL_MIN_MARGIN * 2, _BREAKPOINT[12] = columnSystem(12, COLUMN_UNIT, GUTTER_UNIT) + HORIZONTAL_MIN_MARGIN * 2, _BREAKPOINT);

exports.BORDER_RADIUS = BORDER_RADIUS;
exports.BREAKPOINT = BREAKPOINT;
exports.COLUMN_UNIT = COLUMN_UNIT;
exports.GUTTER_UNIT = GUTTER_UNIT;
exports.HORIZONTAL_MIN_MARGIN = HORIZONTAL_MIN_MARGIN;
exports.SPACING = SPACING;
exports.TYPOGRAPHY_SIZE = TYPOGRAPHY_SIZE;
exports.TYPOGRAPHY_VARIANT = TYPOGRAPHY_VARIANT;
exports.TYPOGRAPHY_WEIGHT = TYPOGRAPHY_WEIGHT;
exports.columnSystem = columnSystem;
//# sourceMappingURL=index.cjs.map
